@@ -18,7 +18,7 @@
 #include <IL/ilut.h>
 
 GLuint
-rilImageGenTexture(const char *filename)
+rilImageGLGenTexture(const char *filename)
 {
 	ILuint image;
 	GLuint texture;
