@@ -20,6 +20,6 @@
 #include <GL/gl.h>
 
 GLuint
-rilImageGenTexture(const char *filename);
+rilImageGLGenTexture(const char *filename);
 
 #endif
